@@ -5,6 +5,9 @@ use compact::{
     CharSet,
     Encoding,
     Header,
+    Operand,
+    Operations,
+    Operator,
 };
 use compact::index::{
     CharStrings,
@@ -13,11 +16,6 @@ use compact::index::{
     Strings,
     Subroutines,
 };
-use compact::operation::{
-    Operand,
-    Operations,
-    Operator,
-};
 
 /// A font set.
 #[derive(Clone, Debug)]
@@ -34,13 +32,15 @@ pub struct FontSet {
     pub local_subroutines: Vec<Subroutines>,
 }
 
+macro_rules! is_i32(($value:ident) => ($value as i32 as Operand == $value));
+
 macro_rules! get_single(
-    ($operations:expr, $operator:ident) => ({
+    ($operations:expr, $operator:ident) => (
         match $operations.get_single(Operator::$operator) {
             Some(value) if is_i32!(value) => value as i32,
             _ => raise!("found a malformed operation"),
         }
-    });
+    );
 );
 
 macro_rules! get_double(
@@ -54,21 +54,15 @@ macro_rules! get_double(
     );
 );
 
-macro_rules! is_i32(
-    ($value:ident) => ($value as i32 as Operand == $value);
-);
-
 impl Value for FontSet {
     fn read<T: Tape>(tape: &mut T) -> Result<Self> {
-        let start = try!(tape.position());
-
+        let position = try!(tape.position());
         let header = try!(tape.take::<Header>());
-        try!(tape.jump(start + header.header_size as u64));
+        try!(tape.jump(position + header.header_size as u64));
         let names = try!(try!(tape.take::<Names>()).into());
         let global_dictionaries = try!(try!(tape.take::<Dictionaries>()).into());
         let strings = try!(tape.take::<Strings>());
         let global_subroutines = try!(tape.take::<Subroutines>());
-
         let mut encodings = vec![];
         let mut char_sets = vec![];
         let mut char_strings = vec![];
@@ -80,37 +74,32 @@ impl Value for FontSet {
                 1 => Encoding::Expert,
                 _ => unimplemented!(),
             });
-
             char_strings.push({
-                try!(tape.jump(start + get_single!(dictionary, CharStrings) as u64));
+                try!(tape.jump(position + get_single!(dictionary, CharStrings) as u64));
                 try!(tape.take_given::<CharStrings>(get_single!(dictionary, CharStringType)))
             });
-
             char_sets.push(match get_single!(dictionary, CharSet) {
                 0 => CharSet::ISOAdobe,
                 1 => CharSet::Expert,
                 2 => CharSet::ExpertSubset,
                 offset => {
-                    try!(tape.jump(start + offset as u64));
+                    try!(tape.jump(position + offset as u64));
                     try!(tape.take_given(char_strings[i].len()))
                 },
             });
-
             local_dictionaries.push({
                 let (size, offset) = get_double!(dictionary, Private);
-                try!(tape.jump(start + offset as u64));
+                try!(tape.jump(position + offset as u64));
                 let chunk = try!(tape.take_given::<Vec<u8>>(size as usize));
                 try!(Cursor::new(chunk).take::<Operations>())
             });
-
             local_subroutines.push({
                 let (_, mut offset) = get_double!(dictionary, Private);
                 offset += get_single!(&local_dictionaries[i], Subrs);
-                try!(tape.jump(start + offset as u64));
+                try!(tape.jump(position + offset as u64));
                 try!(tape.take())
             });
         }
-
         Ok(FontSet {
             header: header,
             names: names,
